@@ -1,8 +1,9 @@
 package Sys::Info::Driver::BSD::Device;
 use strict;
+use warnings;
 use vars qw( $VERSION );
 
-$VERSION = '0.72';
+$VERSION = '0.73';
 
 1;
 
@@ -18,11 +19,8 @@ Sys::Info::Driver::BSD::Device - Base class for BSD device drivers
 
 =head1 DESCRIPTION
 
-This document describes version C<0.72> of C<Sys::Info::Driver::BSD::Device>
-released on C<3 May 2009>.
-
-This document describes version C<0.72> of C<Sys::Info::Driver::BSD::Device>
-released on C<3 May 2009>.
+This document describes version C<0.73> of C<Sys::Info::Driver::BSD::Device>
+released on C<14 January 2010>.
 
 Base class for BSD device drivers.
 
@@ -32,16 +30,16 @@ None.
 
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2009 Burak Grsoy. All rights reserved.
+Copyright 2009 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
